==> core-0.0.58-alpha.29.tgz: package/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [0.0.58-alpha.29](https://github.com/cdmbase/files-stack/compare/v0.0.58-alpha.28...v0.0.58-alpha.29) (2020-05-01)

**Note:** Version bump only for package @files-stack/core





## [0.0.58-alpha.18](https://github.com/cdmbase/files-stack/compare/v0.0.58-alpha.17...v0.0.58-alpha.18) (2020-04-22)

**Note:** Version bump only for package @files-stack/core





## [0.0.58-alpha.15](https://github.com/cdmbase/files-stack/compare/v0.0.58-alpha.14...v0.0.58-alpha.15) (2020-04-04)

**Note:** Version bump only for package @files-stack/core





## [0.0.58-alpha.7](https://github.com/cdmbase/files-stack/compare/v0.0.58-alpha.6...v0.0.58-alpha.7) (2020-03-30)

**Note:** Version bump only for package @files-stack/core





## [0.0.58-alpha.4](https://github.com/cdmbase/files-stack/compare/v0.0.58-alpha.3...v0.0.58-alpha.4) (2020-03-28)

**Note:** Version bump only for package @files-stack/core





## [0.0.58-alpha.0](https://github.com/cdmbase/files-stack/compare/v0.0.56-162...v0.0.58-alpha.0) (2020-03-26)



## [0.0.57](https://github.com/cdmbase/files-stack/compare/v0.0.56...v0.0.57) (2020-03-26)



## [0.0.56](https://github.com/cdmbase/files-stack/compare/v0.0.56-160...v0.0.56) (2020-03-26)



## [0.0.55](https://github.com/cdmbase/files-stack/compare/v0.0.54...v0.0.55) (2019-02-16)



## [0.0.54](https://github.com/cdmbase/files-stack/compare/v0.0.53...v0.0.54) (2018-08-13)



## [0.0.53](https://github.com/cdmbase/files-stack/compare/v0.0.52...v0.0.53) (2018-08-13)



## [0.0.52](https://github.com/cdmbase/files-stack/compare/v0.0.51...v0.0.52) (2018-08-12)



## [0.0.51](https://github.com/cdmbase/files-stack/compare/v0.0.50...v0.0.51) (2018-08-11)



## [0.0.50](https://github.com/cdmbase/files-stack/compare/v0.0.49...v0.0.50) (2018-08-11)



## [0.0.49](https://github.com/cdmbase/files-stack/compare/v0.0.48...v0.0.49) (2018-08-10)



## [0.0.48](https://github.com/cdmbase/files-stack/compare/v0.0.47...v0.0.48) (2018-08-09)



## [0.0.47](https://github.com/cdmbase/files-stack/compare/v0.0.46...v0.0.47) (2018-08-04)



## [0.0.46](https://github.com/cdmbase/files-stack/compare/v0.0.45...v0.0.46) (2018-08-04)



## [0.0.45](https://github.com/cdmbase/files-stack/compare/v0.0.44...v0.0.45) (2018-08-04)



## [0.0.44](https://github.com/cdmbase/files-stack/compare/v0.0.43...v0.0.44) (2018-08-03)



## [0.0.43](https://github.com/cdmbase/files-stack/compare/v0.0.42...v0.0.43) (2018-08-02)



## [0.0.42](https://github.com/cdmbase/files-stack/compare/v0.0.41...v0.0.42) (2018-07-26)



## [0.0.41](https://github.com/cdmbase/files-stack/compare/v0.0.40...v0.0.41) (2018-07-26)



## [0.0.40](https://github.com/cdmbase/files-stack/compare/v0.0.39...v0.0.40) (2018-07-25)



## [0.0.39](https://github.com/cdmbase/files-stack/compare/v0.0.38...v0.0.39) (2018-07-25)



## [0.0.38](https://github.com/cdmbase/files-stack/compare/v0.0.37...v0.0.38) (2018-07-25)



## [0.0.37](https://github.com/cdmbase/files-stack/compare/v0.0.36...v0.0.37) (2018-07-25)



## [0.0.36](https://github.com/cdmbase/files-stack/compare/v0.0.35...v0.0.36) (2018-07-25)



## [0.0.35](https://github.com/cdmbase/files-stack/compare/v0.0.34...v0.0.35) (2018-07-25)



## [0.0.34](https://github.com/cdmbase/files-stack/compare/v0.0.33...v0.0.34) (2018-07-20)



## [0.0.33](https://github.com/cdmbase/files-stack/compare/v0.0.32...v0.0.33) (2018-07-20)



## [0.0.32](https://github.com/cdmbase/files-stack/compare/v0.0.31...v0.0.32) (2018-07-20)



## [0.0.31](https://github.com/cdmbase/files-stack/compare/v0.0.31-3...v0.0.31) (2018-07-10)



## [0.0.31-3](https://github.com/cdmbase/files-stack/compare/v0.0.31-2...v0.0.31-3) (2018-07-08)



## [0.0.31-2](https://github.com/cdmbase/files-stack/compare/v0.0.31-1...v0.0.31-2) (2018-07-07)



## [0.0.31-1](https://github.com/cdmbase/files-stack/compare/v0.0.31-0...v0.0.31-1) (2018-07-06)



## [0.0.31-0](https://github.com/cdmbase/files-stack/compare/v0.0.30...v0.0.31-0) (2018-07-04)



## [0.0.30](https://github.com/cdmbase/files-stack/compare/v0.0.29...v0.0.30) (2018-07-04)



## [0.0.29](https://github.com/cdmbase/files-stack/compare/v0.0.28...v0.0.29) (2018-07-02)



## [0.0.28](https://github.com/cdmbase/files-stack/compare/v0.0.28-39...v0.0.28) (2018-07-02)



## [0.0.28-39](https://github.com/cdmbase/files-stack/compare/v0.0.28-38...v0.0.28-39) (2018-06-23)



## [0.0.28-38](https://github.com/cdmbase/files-stack/compare/v0.0.28-22...v0.0.28-38) (2018-06-20)



## [0.0.28-37](https://github.com/cdmbase/files-stack/compare/v0.0.28-35...v0.0.28-37) (2018-06-20)



## [0.0.28-35](https://github.com/cdmbase/files-stack/compare/v0.0.28-34...v0.0.28-35) (2018-06-20)



## [0.0.28-34](https://github.com/cdmbase/files-stack/compare/v0.0.28-32...v0.0.28-34) (2018-06-20)



## [0.0.28-32](https://github.com/cdmbase/files-stack/compare/v0.0.28-31...v0.0.28-32) (2018-06-20)



## [0.0.28-31](https://github.com/cdmbase/files-stack/compare/v0.0.28-30...v0.0.28-31) (2018-06-19)



## [0.0.28-30](https://github.com/cdmbase/files-stack/compare/v0.0.28-21...v0.0.28-30) (2018-06-19)



## [0.0.28-21](https://github.com/cdmbase/files-stack/compare/v0.0.28-20...v0.0.28-21) (2018-06-14)



## [0.0.28-20](https://github.com/cdmbase/files-stack/compare/v0.0.28-19...v0.0.28-20) (2018-06-12)



## [0.0.28-19](https://github.com/cdmbase/files-stack/compare/v0.0.28-18...v0.0.28-19) (2018-06-09)



## [0.0.28-18](https://github.com/cdmbase/files-stack/compare/v0.0.28-17...v0.0.28-18) (2018-06-08)



## [0.0.28-17](https://github.com/cdmbase/files-stack/compare/v0.0.28-16...v0.0.28-17) (2018-06-07)



## [0.0.28-16](https://github.com/cdmbase/files-stack/compare/v0.0.28-15...v0.0.28-16) (2018-06-07)



## [0.0.28-15](https://github.com/cdmbase/files-stack/compare/v0.0.20...v0.0.28-15) (2018-06-07)

**Note:** Version bump only for package @files-stack/core





## [0.0.57](https://github.com/cdmbase/files-stack/compare/v0.0.56...v0.0.57) (2020-03-26)

**Note:** Version bump only for package @files-stack/core





## [0.0.56](https://github.com/cdmbase/files-stack/compare/v0.0.55...v0.0.56) (2020-03-26)


### Code Refactoring

* **merged `@files-stack/server-common` to `@files-stack/core`:** reduce the number of packages ([d37ff71](https://github.com/cdmbase/files-stack/commit/d37ff716988cd325cd75711f4d68ae268ab3e770))
* **Move redux action for selectFile to apollo client:** Use of `Context`  cache for file Selection ([51fc314](https://github.com/cdmbase/files-stack/commit/51fc314ddcc53c824e9c8021e4af7dc24d5733e5))


### Features

* **redis cache for caching the read content:** faster editing by caching the read content ([6befd5d](https://github.com/cdmbase/files-stack/commit/6befd5d4ebfe51c89baa91da4d6ce257f66deb8a))


### Performance Improvements

* **Improve File Save and Editor:** Save Edited File data incrementally to the server ([805100b](https://github.com/cdmbase/files-stack/commit/805100bc8447c2f6c348ced88741d2fac4d63679)), closes [#302](https://github.com/cdmbase/files-stack/issues/302) [#295](https://github.com/cdmbase/files-stack/issues/295)


### BREAKING CHANGES

* **Move redux action for selectFile to apollo client:** Redux Actions.SELECT_FILE and DESELECT_FILE are now replaced with `useSelectedResourceQuery` to get updates on `selectedFile` and `useUpdateSelectedResourceMutation` for updating the selectedFile.
* **merged `@files-stack/server-common` to `@files-stack/core`:** replace `@files-stack/server-common` with `@files-stack/core`

==> core-0.0.59-alpha.29.tgz: package/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [0.0.59-alpha.29](https://github.com/cdmbase/files-stack/compare/v0.0.59-alpha.28...v0.0.59-alpha.29) (2020-10-06)

**Note:** Version bump only for package @files-stack/core





## [0.0.59-alpha.28](https://github.com/cdmbase/files-stack/compare/v0.0.59-alpha.27...v0.0.59-alpha.28) (2020-10-06)

**Note:** Version bump only for package @files-stack/core





## [0.0.59-alpha.26](https://github.com/cdmbase/files-stack/compare/v0.0.59-alpha.24...v0.0.59-alpha.26) (2020-10-06)

**Note:** Version bump only for package @files-stack/core





## [0.0.59-alpha.19](https://github.com/cdmbase/files-stack/compare/v0.0.59-alpha.18...v0.0.59-alpha.19) (2020-09-18)

**Note:** Version bump only for package @files-stack/core





## [0.0.59-alpha.12](https://github.com/cdmbase/files-stack/compare/v0.0.59-alpha.11...v0.0.59-alpha.12) (2020-08-05)

**Note:** Version bump only for package @files-stack/core





## [0.0.59-alpha.0](https://github.com/cdmbase/files-stack/compare/v0.0.20...v0.0.59-alpha.0) (2020-07-06)


### Code Refactoring

* **merged `@files-stack/server-common` to `@files-stack/core`:** reduce the number of packages ([d37ff71](https://github.com/cdmbase/files-stack/commit/d37ff716988cd325cd75711f4d68ae268ab3e770))
* **Move redux action for selectFile to apollo client:** Use of `Context`  cache for file Selection ([51fc314](https://github.com/cdmbase/files-stack/commit/51fc314ddcc53c824e9c8021e4af7dc24d5733e5))


### Features

* **redis cache for caching the read content:** faster editing by caching the read content ([6befd5d](https://github.com/cdmbase/files-stack/commit/6befd5d4ebfe51c89baa91da4d6ce257f66deb8a))


### Performance Improvements

* **Improve File Save and Editor:** Save Edited File data incrementally to the server ([805100b](https://github.com/cdmbase/files-stack/commit/805100bc8447c2f6c348ced88741d2fac4d63679)), closes [#302](https://github.com/cdmbase/files-stack/issues/302) [#295](https://github.com/cdmbase/files-stack/issues/295)


### BREAKING CHANGES

* **Move redux action for selectFile to apollo client:** Redux Actions.SELECT_FILE and DESELECT_FILE are now replaced with `useSelectedResourceQuery` to get updates on `selectedFile` and `useUpdateSelectedResourceMutation` for updating the selectedFile.
* **merged `@files-stack/server-common` to `@files-stack/core`:** replace `@files-stack/server-common` with `@files-stack/core`





## [0.0.58-alpha.59](https://github.com/cdmbase/files-stack/compare/v0.0.20...v0.0.58-alpha.59) (2020-07-06)


### Code Refactoring

* **merged `@files-stack/server-common` to `@files-stack/core`:** reduce the number of packages ([d37ff71](https://github.com/cdmbase/files-stack/commit/d37ff716988cd325cd75711f4d68ae268ab3e770))
* **Move redux action for selectFile to apollo client:** Use of `Context`  cache for file Selection ([51fc314](https://github.com/cdmbase/files-stack/commit/51fc314ddcc53c824e9c8021e4af7dc24d5733e5))


### Features

* **redis cache for caching the read content:** faster editing by caching the read content ([6befd5d](https://github.com/cdmbase/files-stack/commit/6befd5d4ebfe51c89baa91da4d6ce257f66deb8a))


### Performance Improvements

* **Improve File Save and Editor:** Save Edited File data incrementally to the server ([805100b](https://github.com/cdmbase/files-stack/commit/805100bc8447c2f6c348ced88741d2fac4d63679)), closes [#302](https://github.com/cdmbase/files-stack/issues/302) [#295](https://github.com/cdmbase/files-stack/issues/295)


### BREAKING CHANGES

* **Move redux action for selectFile to apollo client:** Redux Actions.SELECT_FILE and DESELECT_FILE are now replaced with `useSelectedResourceQuery` to get updates on `selectedFile` and `useUpdateSelectedResourceMutation` for updating the selectedFile.
* **merged `@files-stack/server-common` to `@files-stack/core`:** replace `@files-stack/server-common` with `@files-stack/core`
